@@ -342,9 +342,9 @@ pub trait Exti {
     ///
     /// let mut dp: pac::Peripherals = pac::Peripherals::take().unwrap();
     /// C6::set_port(&mut dp.SYSCFG);
-    /// C6::set_falling_trggier(&mut dp.EXTI, true);
+    /// C6::set_falling_trigger(&mut dp.EXTI, true);
     /// ```
-    fn set_falling_trggier(exti: &mut pac::EXTI, en: bool);
+    fn set_falling_trigger(exti: &mut pac::EXTI, en: bool);
 
     /// Set the core 1 interrupt mask in the EXTI.
     ///
@@ -376,7 +376,7 @@ pub trait Exti {
     /// [`gpio-button-irq.rs`]: https://github.com/stm32-rs/stm32wlxx-hal/blob/main/examples/examples/gpio-button-irq.rs
     fn clear_exti();
 
-    /// Returns true if a trigger request occured.
+    /// Returns true if a trigger request occurred.
     ///
     /// # Example
     ///
@@ -390,7 +390,7 @@ pub trait Exti {
     /// This is a helper function that wraps:
     /// 1. [`set_port`](Self::set_port)
     /// 2. [`set_rising_trigger`](Self::set_rising_trigger)
-    /// 3. [`set_falling_trggier`](Self::set_falling_trggier)
+    /// 3. [`set_falling_trigger`](Self::set_falling_trigger)
     /// 4. Unmask with [`set_c1_mask`](Self::set_c1_mask)
     ///
     /// # Example
@@ -409,7 +409,7 @@ pub trait Exti {
     fn setup_exti_c1(exti: &mut pac::EXTI, syscfg: &mut pac::SYSCFG, trg: ExtiTrg) {
         Self::set_port(syscfg);
         Self::set_rising_trigger(exti, matches!(trg, ExtiTrg::Rising | ExtiTrg::Both));
-        Self::set_falling_trggier(exti, matches!(trg, ExtiTrg::Falling | ExtiTrg::Both));
+        Self::set_falling_trigger(exti, matches!(trg, ExtiTrg::Falling | ExtiTrg::Both));
         Self::set_c1_mask(exti, true);
     }
 
@@ -768,7 +768,7 @@ pub mod pins {
                     }
 
                     #[inline]
-                    fn set_falling_trggier(exti: &mut pac::EXTI, en: bool) {
+                    fn set_falling_trigger(exti: &mut pac::EXTI, en: bool) {
                         exti.ftsr1.modify(|_, w| w.[<ft $n>]().bit(en));
                     }
 
@@ -959,6 +959,15 @@ impl PortA {
         rcc.ahb2enr.read(); // delay after an RCC peripheral clock enabling
     }
 
+    /// Set the IO port clock enable during sleep mode.
+    ///
+    /// * `false`: Clock disabled during Sleep and Stop modes
+    /// * `true`: Clock enabled during Sleep mode, disabled during Stop mode
+    #[inline]
+    pub fn set_sleep_clock(rcc: &mut pac::RCC, enable: bool) {
+        rcc.ahb2smenr.modify(|_, w| w.gpioasmen().bit(enable));
+    }
+
     /// Get the input level of all pins on this port.
     #[inline]
     pub fn input_level() -> u16 {
@@ -1094,6 +1103,15 @@ impl PortB {
         rcc.ahb2enr.read(); // delay after an RCC peripheral clock enabling
     }
 
+    /// Set the IO port clock enable during sleep mode.
+    ///
+    /// * `false`: Clock disabled during Sleep and Stop modes
+    /// * `true`: Clock enabled during Sleep mode, disabled during Stop mode
+    #[inline]
+    pub fn set_sleep_clock(rcc: &mut pac::RCC, enable: bool) {
+        rcc.ahb2smenr.modify(|_, w| w.gpiobsmen().bit(enable));
+    }
+
     /// Get the input level of all pins on this port.
     #[inline]
     pub fn input_level() -> u16 {
@@ -1217,6 +1235,15 @@ impl PortC {
         rcc.ahb2enr.read(); // delay after an RCC peripheral clock enabling
     }
 
+    /// Set the IO port clock enable during sleep mode.
+    ///
+    /// * `false`: Clock disabled during Sleep and Stop modes
+    /// * `true`: Clock enabled during Sleep mode, disabled during Stop mode
+    #[inline]
+    pub fn set_sleep_clock(rcc: &mut pac::RCC, enable: bool) {
+        rcc.ahb2smenr.modify(|_, w| w.gpiocsmen().bit(enable));
+    }
+
     /// Get the input level of all pins on this port.
     #[inline]
     pub fn input_level() -> u16 {
