@@ -202,6 +202,22 @@ pub fn rfbusyms() -> bool {
     unsafe { (*pac::PWR::PTR).sr2.read().rfbusyms().is_busy() }
 }
 
+#[inline]
+fn hold_reset(rcc: &mut pac::RCC) {
+    rcc.csr.modify(|_, w| w.rfrst().set_bit());
+}
+
+#[inline]
+fn release_reset(rcc: &mut pac::RCC) {
+    rcc.csr.modify(|_, w| w.rfrst().clear_bit());
+}
+
+#[inline]
+fn pulse_reset(rcc: &mut pac::RCC) {
+    hold_reset(rcc);
+    release_reset(rcc);
+}
+
 /// Sub-GHz radio peripheral.
 ///
 /// # Example
@@ -352,7 +368,7 @@ impl<MISO, MOSI> SubGhz<MISO, MOSI> {
     /// 2. You cannot use the SPI bus while the clock is disabled.
     /// 3. You are responsible for re-enabling the clock before resuming use
     ///    of the SPI bus.
-    /// 4. You are reponsible for setting up anything that may have lost state
+    /// 4. You are responsible for setting up anything that may have lost state
     ///    while the clock was disabled.
     pub unsafe fn disable_spi_clock(rcc: &mut pac::RCC) {
         Spi3::<SgMiso, SgMosi>::disable_clock(rcc)
@@ -363,11 +379,6 @@ impl<MISO, MOSI> SubGhz<MISO, MOSI> {
         Spi3::<SgMiso, SgMosi>::enable_clock(rcc)
     }
 
-    fn pulse_radio_reset(rcc: &mut pac::RCC) {
-        rcc.csr.modify(|_, w| w.rfrst().set_bit());
-        rcc.csr.modify(|_, w| w.rfrst().clear_bit());
-    }
-
     fn poll_not_busy(&self) {
         // TODO: this is a terrible timeout
         let mut count: u32 = 1_000_000;
@@ -457,13 +468,35 @@ impl SubGhz<SgMiso, SgMosi> {
     /// let sg = SubGhz::new(dp.SPI3, &mut dp.RCC);
     /// ```
     pub fn new(spi: pac::SPI3, rcc: &mut pac::RCC) -> SubGhz<SgMiso, SgMosi> {
-        Self::pulse_radio_reset(rcc);
+        pulse_reset(rcc);
+        // safety: radio has been reset
+        unsafe { Self::new_no_reset(spi, rcc) }
+    }
 
+    /// Create a new sub-GHz radio driver from a peripheral.
+    ///
+    /// Same as `new`, but without a reset.
+    /// This is useful when waking up from standby to handle a radio interrupt.
+    ///
+    /// # Safety
+    ///
+    /// This will not reset the radio, the radio will be in an unknown state
+    /// when constructed with this method.
+    ///
+    /// # Example
+    ///
+    /// ```no_run
+    /// use stm32wlxx_hal::{pac, subghz::SubGhz};
+    ///
+    /// let mut dp: pac::Peripherals = pac::Peripherals::take().unwrap();
+    ///
+    /// let sg = unsafe { SubGhz::new_no_reset(dp.SPI3, &mut dp.RCC) };
+    /// ```
+    #[allow(unused_unsafe)]
+    pub unsafe fn new_no_reset(spi: pac::SPI3, rcc: &mut pac::RCC) -> SubGhz<SgMiso, SgMosi> {
         let spi: Spi3<SgMiso, SgMosi> = Spi3::new(spi, baud_rate(rcc), rcc);
-
         unsafe { wakeup() };
-
-        SubGhz { spi }
+        Self { spi }
     }
 
     /// Steal the SubGHz peripheral from whatever is currently using it.
@@ -517,13 +550,44 @@ impl<MISO: DmaCh, MOSI: DmaCh> SubGhz<MISO, MOSI> {
         mosi_dma: MOSI,
         rcc: &mut pac::RCC,
     ) -> Self {
-        Self::pulse_radio_reset(rcc);
+        pulse_reset(rcc);
+        // safety: radio has been reset
+        unsafe { Self::new_with_dma_no_reset(spi, miso_dma, mosi_dma, rcc) }
+    }
 
+    /// Create a new sub-GHz radio driver from a peripheral and two DMA
+    /// channels.
+    ///
+    /// Same as `new_with_dma`, but without a reset.
+    /// This is useful when waking up from standby to handle a radio interrupt.
+    ///
+    /// # Safety
+    ///
+    /// This will not reset the radio, the radio will be in an unknown state
+    /// when constructed with this method.
+    ///
+    /// # Example
+    ///
+    /// ```no_run
+    /// use stm32wlxx_hal::{dma::AllDma, pac, subghz::SubGhz};
+    ///
+    /// let mut dp: pac::Peripherals = pac::Peripherals::take().unwrap();
+    ///
+    /// let dma: AllDma = AllDma::split(dp.DMAMUX, dp.DMA1, dp.DMA2, &mut dp.RCC);
+    ///
+    /// let sg = unsafe { SubGhz::new_with_dma_no_reset(dp.SPI3, dma.d1.c1, dma.d2.c1, &mut dp.RCC) };
+    /// ```
+    #[allow(unused_unsafe)]
+    pub unsafe fn new_with_dma_no_reset(
+        spi: pac::SPI3,
+        miso_dma: MISO,
+        mosi_dma: MOSI,
+        rcc: &mut pac::RCC,
+    ) -> Self {
+        release_reset(rcc);
         let spi: Spi3<MISO, MOSI> =
             Spi3::new_with_dma(spi, miso_dma, mosi_dma, baud_rate(rcc), rcc);
-
         unsafe { wakeup() };
-
         SubGhz { spi }
     }
 
@@ -690,12 +754,36 @@ where
         self.write(wr_reg![PAOCP, ocp as u8])
     }
 
-    /// Set the HSE32 crystal OSC_IN load capaitor trimming.
+    /// Restart the radio RTC.
+    ///
+    /// This is used to workaround an erratum for [`set_rx_duty_cycle`].
+    ///
+    /// [`set_rx_duty_cycle`]: crate::subghz::SubGhz::set_rx_duty_cycle
+    pub fn restart_rtc(&mut self) -> Result<(), Error> {
+        self.write(wr_reg![RTCCTLR, 0b1])
+    }
+
+    /// Set the radio real-time-clock period.
+    ///
+    /// This is used to workaround an erratum for [`set_rx_duty_cycle`].
+    ///
+    /// [`set_rx_duty_cycle`]: crate::subghz::SubGhz::set_rx_duty_cycle
+    pub fn set_rtc_period(&mut self, period: Timeout) -> Result<(), Error> {
+        let tobits: u32 = period.into_bits();
+        self.write(wr_reg![
+            RTCPRDR2,
+            (tobits >> 16) as u8,
+            (tobits >> 8) as u8,
+            tobits as u8
+        ])
+    }
+
+    /// Set the HSE32 crystal OSC_IN load capacitor trimming.
     pub fn set_hse_in_trim(&mut self, trim: HseTrim) -> Result<(), Error> {
         self.write(wr_reg![HSEINTRIM, trim.into()])
     }
 
-    /// Set the HSE32 crystal OSC_OUT load capaitor trimming.
+    /// Set the HSE32 crystal OSC_OUT load capacitor trimming.
     pub fn set_hse_out_trim(&mut self, trim: HseTrim) -> Result<(), Error> {
         self.write(wr_reg![HSEOUTTRIM, trim.into()])
     }
@@ -875,8 +963,39 @@ where
     /// * if [`set_standby`] is sent during the listening period or after the
     ///   sub-GHz has been requested to exit sleep mode by sub-GHz radio SPI NSS
     ///
+    /// # Erratum
+    ///
+    /// When a preamble is detected the radio should restart the RX timeout
+    /// with a value of 2 × `rx_period` + `sleep_period`.
+    /// Instead the radio erroneously uses `sleep_period`.
+    ///
+    /// To workaround this use [`restart_rtc`] and [`set_rtc_period`] to
+    /// reprogram the radio timeout to  2 × `rx_period` + `sleep_period`.
+    ///
+    /// Use code similar to this in the [`PreambleDetected`] interrupt handler.
+    ///
+    /// ```no_run
+    /// # let rx_period: Timeout = Timeout::from_millis_sat(100);
+    /// # let sleep_period: Timeout = Timeout::from_millis_sat(100);
+    /// # let mut sg = unsafe { stm32wlxx_hal::subghz::SubGhz::steal() };
+    /// use stm32wlxx_hal::subghz::Timeout;
+    ///
+    /// let period: Timeout = rx_period
+    ///     .saturating_add(rx_period)
+    ///     .saturating_add(sleep_period);
+    ///
+    /// sg.set_rtc_period(period)?;
+    /// sg.restart_rtc()?;
+    /// # Ok::<(), stm32wlxx_hal::subghz::Error>(())
+    /// ```
+    ///
+    /// Please read the erratum for more details.
+    ///
+    /// [`PreambleDetected`]: crate::subghz::Irq::PreambleDetected
+    /// [`restart_rtc`]: crate::subghz::SubGhz::restart_rtc
     /// [`RxDone`]: crate::subghz::Irq::RxDone
     /// [`set_rf_frequency`]: crate::subghz::SubGhz::set_rf_frequency
+    /// [`set_rtc_period`]: crate::subghz::SubGhz::set_rtc_period
     /// [`set_standby`]: crate::subghz::SubGhz::set_standby
     pub fn set_rx_duty_cycle(
         &mut self,
@@ -961,7 +1080,7 @@ where
         self.write(params.as_slice())
     }
 
-    /// Power amplifier configuation.
+    /// Power amplifier configuration.
     ///
     /// Used to customize the maximum output power and efficiency.
     pub fn set_pa_config(&mut self, pa_config: &PaConfig) -> Result<(), Error> {
@@ -1049,7 +1168,6 @@ where
     /// Get the RX buffer status.
     ///
     /// The return tuple is (status, payload_length, buffer_pointer).
-
     pub fn rx_buffer_status(&mut self) -> Result<(Status, u8, u8), Error> {
         let data: [u8; 3] = self.read_n(OpCode::GetRxBufferStatus)?;
         Ok((data[0].into(), data[1], data[2]))
@@ -1151,7 +1269,7 @@ where
     /// Get the radio operational errors.
     pub fn op_error(&mut self) -> Result<(Status, u16), Error> {
         let data: [u8; 3] = self.read_n(OpCode::GetError)?;
-        Ok((data[0].into(), u16::from_le_bytes([data[1], data[2]])))
+        Ok((data[0].into(), u16::from_be_bytes([data[1], data[2]])))
     }
 
     /// Clear all errors as reported by [`op_error`](SubGhz::op_error).
@@ -1256,6 +1374,16 @@ pub(crate) enum Register {
     RXGAINC = 0x08AC,
     /// PA over current protection.
     PAOCP = 0x08E7,
+    /// RTC control.
+    RTCCTLR = 0x0902,
+    /// RTC period MSB.
+    RTCPRDR2 = 0x0906,
+    /// RTC period mid-byte.
+    #[allow(dead_code)]
+    RTCPRDR1 = 0x0907,
+    /// RTC period LSB.
+    #[allow(dead_code)]
+    RTCPRDR0 = 0x0908,
     /// HSE32 OSC_IN capacitor trim.
     HSEINTRIM = 0x0911,
     /// HSE32 OSC_OUT capacitor trim.
